##  Storing Resources on Fact Sheets
SAP LeanIX allows you to store different types of resources directly on the fact sheet as an additional source of information. You can store the following:
  * Link External Resources: You can add links to external resources with names and descriptions.
  * Files: You can upload files up to 10 MB. Uploaded files are then visible in the Resources tab. Image files can be previewed by clicking on them, while other file types get downloaded when clicked.
  * Diagrams: You can link diagrams in your workspace to fact sheets for easy access, and these linked diagrams are visible in both the Resources tab and the fact sheet's side panel. Linked diagrams do not necessarily contain the fact sheet itself and will remain visible even if the fact sheet is removed from them. In contrast, the resources tab also lists all diagrams that include this fact sheet, and this list is automatically updated if the fact sheet is removed from any of those diagrams.
  * Logos: You can upload an image file of up to 1 MB. The image is then used as a logo for that fact sheet in the portal. Supported formats include - .png, .jpg, .gif.


To store the resources, do the following:
  1. Navigate to the Resources tab of the fact sheet.
  2. Click +Add a resource. It opens a modal to add the resources.
  3. In the modal, select the required tab based on your need, then link or upload the resource.
  4. Click Save or Upload to finish adding.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio85be7d09d2264f2ea2331f89f89ec6e1_LowRes.gif)
Storing Resources on Fact Sheets
